@@ -21,19 +21,18 @@ from . import utils
 
 JINJA2_ENVIRONMENT_OPTIONS = getattr(settings, "JINJA2_ENVIRONMENT_OPTIONS", {})
 JINJA2_EXTENSIONS = getattr(settings, "JINJA2_EXTENSIONS", [])
-JINJA2_FILTERS = getattr(settings, "JINJA2_FILTERS", {})
-JINJA2_FILTERS_REPLACE_FROM_DJANGO = getattr(settings, "JINJA2_FILTERS_REPLACE_FROM_DJANGO", True)
-JINJA2_TESTS = getattr(settings, "JINJA2_TESTS", {})
-JINJA2_GLOBALS = getattr(settings, "JINJA2_GLOBALS", {})
 JINJA2_AUTOESCAPE = getattr(settings, "JINJA2_AUTOESCAPE", True)
 JINJA2_NEWSTYLE_GETTEXT = getattr(settings, "JINJA2_NEWSTYLE_GETTEXT", True)
-JINJA2_CONSTANTS = getattr(settings, "JINJA2_CONSTANTS", {})
+JINJA2_FILTERS_REPLACE_FROM_DJANGO = getattr(settings, "JINJA2_FILTERS_REPLACE_FROM_DJANGO", True)
 
 JINJA2_BYTECODE_CACHE_ENABLE = getattr(settings, "JINJA2_BYTECODE_CACHE_ENABLE", False)
 JINJA2_BYTECODE_CACHE_NAME = getattr(settings, "JINJA2_BYTECODE_CACHE_NAME", "default")
 JINJA2_BYTECODE_CACHE_BACKEND = getattr(settings, "JINJA2_BYTECODE_CACHE_BACKEND",
                                         "django_jinja.cache.BytecodeCache")
 
+JINJA2_CONSTANTS = getattr(settings, "JINJA2_CONSTANTS", {})
+JINJA2_TESTS = getattr(settings, "JINJA2_TESTS", {})
+
 
 # Default jinja extension list
 DEFAULT_EXTENSIONS = [
@@ -45,13 +44,13 @@ DEFAULT_EXTENSIONS = [
 ]
 
 
-JINJA2_FILTERS.update({
+JINJA2_FILTERS = {
     "static": "django_jinja.builtins.filters.static",
     "reverseurl": "django_jinja.builtins.filters.reverse",
     "addslashes": "django_jinja.builtins.filters.addslashes",
     "capfirst": "django_jinja.builtins.filters.capfirst",
     "escapejs": "django_jinja.builtins.filters.escapejs_filter",
-    "fix_ampersands": "django_jinja.builtins.filters.fix_ampersands_filter",
+    # "fix_ampersands": "django_jinja.builtins.filters.fix_ampersands_filter",
     "floatformat": "django_jinja.builtins.filters.floatformat",
     "iriencode": "django_jinja.builtins.filters.iriencode",
     "linenumbers": "django_jinja.builtins.filters.linenumbers",
@@ -81,7 +80,7 @@ JINJA2_FILTERS.update({
     "localtime": "django_jinja.builtins.filters.localtime",
     "utc": "django_jinja.builtins.filters.utc",
     "timezone": "django_jinja.builtins.filters.timezone",
-})
+}
 
 if JINJA2_FILTERS_REPLACE_FROM_DJANGO:
     JINJA2_FILTERS.update({
@@ -101,13 +100,17 @@ if JINJA2_FILTERS_REPLACE_FROM_DJANGO:
         "pprint": "django_jinja.builtins.filters.pprint",
     })
 
-JINJA2_GLOBALS.update({
+JINJA2_GLOBALS = {
     "url": "django_jinja.builtins.global_context.url",
     "static": "django_jinja.builtins.global_context.static",
     "localtime": "django_jinja.builtins.filters.localtime",
     "utc": "django_jinja.builtins.filters.utc",
     "timezone": "django_jinja.builtins.filters.timezone",
-})
+}
+
+
+JINJA2_FILTERS.update(getattr(settings, "JINJA2_FILTERS", {}))
+JINJA2_GLOBALS.update(getattr(settings, "JINJA2_GLOBALS", {}))
 
 
 def dict_from_context(context):
@@ -196,6 +199,16 @@ class Environment(Environment):
             return
 
         from django.utils import safestring
+        from django.forms.forms import BoundField
+
+        try:
+            from django.forms.utils import ErrorList
+            from django.forms.utils import ErrorDict
+
+        # Just for django < 1.7 compatibility
+        except ImportError:
+            from django.forms.util import ErrorList
+            from django.forms.util import ErrorDict
 
         if hasattr(safestring, "SafeText"):
             if not hasattr(safestring.SafeText, "__html__"):
@@ -213,6 +226,15 @@ class Environment(Environment):
             if not hasattr(safestring.SafeBytes, "__html__"):
                 safestring.SafeBytes.__html__ = lambda self: six.text_type(self)
 
+        if not hasattr(BoundField, "__html__"):
+            BoundField.__html__ = lambda self: six.text_type(self)
+
+        if not hasattr(ErrorList, "__html__"):
+            ErrorList.__html__ = lambda self: six.text_type(self)
+
+        if not hasattr(ErrorDict, "__html__"):
+            ErrorDict.__html__ = lambda self: six.text_type(self)
+
     def initialize_builtins(self):
         for name, value in JINJA2_FILTERS.items():
             if isinstance(value, six.string_types):
